@@ -7,6 +7,7 @@ import (
 	"os"
 	"os/signal"
 	"runtime"
+	"strings"
 	"syscall"
 
 	"github.com/pkg/errors"
@@ -16,7 +17,7 @@ import (
 	"github.com/jonaslu/ain/internal/pkg/parse"
 )
 
-var version = "1.4.1"
+var version = "1.5.0"
 var gitSha = "develop"
 
 const bashSignalCaughtBase = 128
@@ -106,25 +107,63 @@ Project home page: https://github.com/jonaslu/ain`
 	}
 
 	if fatal != "" {
+		// Is this valid?
 		checkSignalRaisedAndExit(assembledCtx, signalRaised)
 
 		fmt.Fprintln(os.Stderr, fatal)
 		os.Exit(1)
 	}
 
-	backendOutput, err := call.CallBackend(assembledCtx, backendInput, leaveTmpFile, printCommand)
+	backendInput.PrintCommand = printCommand
+
+	call, err := call.Setup(backendInput)
 	if err != nil {
-		checkSignalRaisedAndExit(assembledCtx, signalRaised)
+		printInternalErrorAndExit(err)
+	}
 
-		fmt.Fprint(os.Stderr, err)
+	if printCommand {
+		// Tempfile always left when calling as string
+		fmt.Fprint(os.Stdout, call.CallAsString())
+		return
+	}
 
-		var backendErr *call.BackedErr
-		if errors.As(err, &backendErr) {
-			os.Exit(backendErr.ExitCode)
+	var errors []string
+	backendInput.LeaveTempFile = leaveTmpFile
+	backendOutput, err := call.CallAsCmd(assembledCtx)
+
+	teardownErr := call.Teardown()
+	if teardownErr != nil {
+		errors = append(errors, teardownErr.Error())
+	}
+
+	if err != nil && assembledCtx.Err() != context.Canceled {
+		errors = append(errors, err.Error())
+	}
+
+	if len(errors) > 0 {
+		errorMsg := "Error"
+		if len(errors) > 1 {
+			errorMsg += "s:\n"
+		} else {
+			errorMsg += ": "
 		}
 
+		errorMsg += strings.Join(errors, "\n") + "\n"
+		fmt.Fprintln(os.Stderr, errorMsg)
+	}
+
+	if backendOutput != nil {
+		// It's customary to print stderr first
+		// to get the users attention on the error
+		fmt.Fprint(os.Stderr, backendOutput.Stderr)
+		fmt.Fprint(os.Stdout, backendOutput.Stdout)
+	}
+
+	checkSignalRaisedAndExit(assembledCtx, signalRaised)
+
+	if assembledCtx.Err() == context.DeadlineExceeded || teardownErr != nil {
 		os.Exit(1)
 	}
 
-	fmt.Fprint(os.Stdout, backendOutput)
+	os.Exit(backendOutput.ExitCode)
 }
