@@ -2,19 +2,16 @@ package call
 
 import (
 	"context"
-	"os"
 	"os/exec"
 	"regexp"
 	"strings"
 
 	"github.com/jonaslu/ain/internal/pkg/data"
 	"github.com/jonaslu/ain/internal/pkg/utils"
-	"github.com/pkg/errors"
 )
 
 type wget struct {
 	backendInput *data.BackendInput
-	tmpFileName  string
 	binaryName   string
 }
 
@@ -71,22 +68,15 @@ func (wget *wget) getMethodArgument(escape bool) string {
 	return ""
 }
 
-func (wget *wget) getBodyArgument(tmpDir string) (string, error) {
-	if len(wget.backendInput.Body) > 0 {
-		tmpFile, err := wget.backendInput.GetBodyAsTempFile(tmpDir)
-
-		if err != nil {
-			return "", err
-		}
-
-		wget.tmpFileName = tmpFile.Name()
-		return "--body-file=" + tmpFile.Name(), nil
+func (wget *wget) getBodyArgument() []string {
+	if wget.backendInput.TempFileName != "" {
+		return []string{"--body-file=" + wget.backendInput.TempFileName}
 	}
 
-	return "", nil
+	return []string{}
 }
 
-func (wget *wget) runAsCmd(ctx context.Context) ([]byte, error) {
+func (wget *wget) getAsCmd(ctx context.Context) *exec.Cmd {
 	args := []string{}
 	for _, backendOpt := range wget.backendInput.BackendOptions {
 		args = append(args, backendOpt...)
@@ -97,31 +87,15 @@ func (wget *wget) runAsCmd(ctx context.Context) ([]byte, error) {
 	}
 
 	args = append(args, wget.getHeaderArguments(false)...)
-
-	if len(wget.backendInput.Body) > 0 {
-		bodyArgs, err := wget.getBodyArgument("")
-		if err != nil {
-			return nil, err
-		}
-
-		args = append(args, bodyArgs)
-	}
+	args = append(args, wget.getBodyArgument()...)
 
 	args = append(args, wget.backendInput.Host.String())
 
 	wgetCmd := exec.CommandContext(ctx, wget.binaryName, args...)
-	output, err := wgetCmd.CombinedOutput()
-	if err != nil {
-		return output, &BackedErr{
-			Err:      err,
-			ExitCode: wgetCmd.ProcessState.ExitCode(),
-		}
-	}
-
-	return output, nil
+	return wgetCmd
 }
 
-func (wget *wget) getAsString() (string, error) {
+func (wget *wget) getAsString() string {
 	args := [][]string{}
 
 	for _, optionLine := range wget.backendInput.BackendOptions {
@@ -140,19 +114,7 @@ func (wget *wget) getAsString() (string, error) {
 		args = append(args, []string{header})
 	}
 
-	cwd, err := os.Getwd()
-	if err != nil {
-		return "", errors.Wrap(err, "Could not get current working dir, cannot store any body temp-file")
-	}
-
-	if len(wget.backendInput.Body) > 0 {
-		bodyArg, err := wget.getBodyArgument(cwd)
-		if err != nil {
-			return "", err
-		}
-
-		args = append(args, []string{bodyArg})
-	}
+	args = append(args, wget.getBodyArgument())
 
 	args = append(args, []string{
 		utils.EscapeForShell(wget.backendInput.Host.String()),
@@ -160,13 +122,5 @@ func (wget *wget) getAsString() (string, error) {
 
 	output := wget.binaryName + " " + utils.PrettyPrintStringsForShell(args)
 
-	return output, nil
-}
-
-func (wget *wget) cleanUp() error {
-	if wget.tmpFileName != "" {
-		return os.Remove(wget.tmpFileName)
-	}
-
-	return nil
+	return output
 }
