@@ -68,8 +68,8 @@ func captureEditorOutput(tempFile *os.File) (string, error) {
 	return string(tempFileContents), nil
 }
 
-func readEditedTemplate(sourceTemplateFileName string) (str string, err error) {
-	sourceTemplate, err := os.Open(sourceTemplateFileName)
+func readEditedRawTemplateString(sourceTemplateFileName string) (string, error) {
+	rawTemplateString, err := os.Open(sourceTemplateFileName)
 	if err != nil {
 		return "", errors.Wrapf(err, "Cannot open source template file %s", sourceTemplateFileName)
 	}
@@ -92,17 +92,17 @@ func readEditedTemplate(sourceTemplateFileName string) (str string, err error) {
 		}
 	}()
 
-	writtenLen, err := io.Copy(tempFile, sourceTemplate)
-	if writtenLen == 0 {
+	_, err = io.Copy(tempFile, rawTemplateString)
+	if err != nil {
 		return "", errors.Wrap(err, "Cannot copy source template file to temp-file")
 	}
 
 	return captureEditorOutput(tempFile)
 }
 
-func ReadTemplate(templateFileName string) (string, error) {
+func ReadRawTemplateString(templateFileName string) (string, error) {
 	if strings.HasSuffix(templateFileName, editFileSuffix) {
-		return readEditedTemplate(strings.TrimSuffix(templateFileName, editFileSuffix))
+		return readEditedRawTemplateString(strings.TrimSuffix(templateFileName, editFileSuffix))
 	}
 
 	fileContents, err := ioutil.ReadFile(templateFileName)
